@@ -1,8 +1,12 @@
 import praw
 import os
+import sys
 from . import botfiles
 from sty import fg
 
+if sys.platform == 'win32':
+    os.system('color')
+
 debug = False
 roundfile = botfiles.rounds
 archivefile = botfiles.archive
@@ -10,7 +14,7 @@ cwd = os.getcwd()
 try:
     os.chdir(botfiles.botconfig)
     reddit = praw.Reddit('botterino')
-    print(f'{fg.green}Successfully logged into reddit as {reddit.user.me()}')
+    print(f'{fg.green}Sucessfully logged into reddit as {reddit.user.me()}')
 except Exception as e:
     print(f'{fg.red}Unable to login to reddit. Please check {botfiles.prawconfig}')
     print(f'{fg.red}{e}')
